#
# spec file for package libosmo-sigtran
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libosmo-sigtran
Version:        2.1.1
Release:        1.1
%define libversion 2_0_0
Summary:        Osmocom library for the A-bis interface between BTS and BSC
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://gitea.osmocom.org/osmocom/libosmo-sigtran
Source:         %name-%version.tar.xz
#server broken#Source: https://gitea.osmocom.org/osmocom/libosmo-sigtran/archive/%%version.tar.gz
Patch2:         0001-build-fixes.patch
Patch3:         harden_osmo-stp.service.patch
BuildRequires:  automake >= 1.6
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libosmo-netif) >= 1.6.0
BuildRequires:  pkgconfig(libosmocore) >= 1.11.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.11.0
BuildRequires:  pkgconfig(libosmovty) >= 1.11.0

%description
libosmo-sigtran is a C-language library implementation of a variety
of telecom signaling protocols, such as M3UA, SUA, SCCP.

%package -n libosmo-sigtran11
Summary:        Osmocom SIGTRAN library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-sigtran11
libosmo-sigtran is a C-language library implementation of a variety
of telecom signaling protocols, such as M3UA, SUA, SCCP (connection
oriented and connectionless). SCCP is a network layer protocol that
provides extended routing, flow control, segmentation,
connection-orientation, and error correction facilities in Signaling
System 7 telecommunications networks. SCCP is heavily used in
cellular networks such as GSM.

OsmoSTP is a SS7 Transfer Point that can be used to act as router and
translator between M3UA, SUA and/or SCCPlite.

%package -n libosmo-sigtran-devel
Summary:        Development files for the Osmocom sigtran library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-sigtran11 = %version

%description -n libosmo-sigtran-devel
Osmocom implementation of (parts of) SIGTRAN.

This subpackage contains the development files for the Osmocom
SIGTRAN library.

%package -n osmo-stp
Summary:        Osmocom SIGTRAN STP (Signaling Transfer Point)
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Servers

%description -n osmo-stp
This is the Osmocom (Open Source Mobile Communications)
implementation of a Signaling Transfer Point (STP) for SS7/SIGTRAN
telecommunication networks. At this point, it is a minimal
implementation, missing lots of the functionality usually present in
a STP, such as Global Title Routing, Global Title Translation.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
# bugzilla.opensuse.org/795968 for rationale
%configure --includedir="%_includedir/%name" \
	--docdir="%_defaultdocdir/%name" \
	--with-systemdsystemunitdir="%_unitdir" \
	--disable-static CFLAGS="%optflags -fcommon"
%make_build

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete

%check
if ! %make_build check; then
	find . -name testsuite.log -exec cat "{}" "+"
%ifnarch ppc64 sparc64 s390x
	# still BE problems?
	exit 1
%endif
fi

%ldconfig_scriptlets -n libosmo-sigtran11

%preun -n osmo-stp
%service_del_preun osmo-stp.service

%postun -n osmo-stp
%service_del_postun osmo-stp.service

%pre -n osmo-stp
%service_add_pre osmo-stp.service

%post -n osmo-stp
%service_add_post osmo-stp.service

%files -n libosmo-sigtran11
%_libdir/libosmo-sigtran.so.*

%files -n libosmo-sigtran-devel
%_includedir/%name/
%_libdir/libosmo-sigtran.so
%_libdir/pkgconfig/libosmo-sigtran.pc

%files -n osmo-stp
%dir %_sysconfdir/osmocom
%config %_sysconfdir/osmocom/osmo-stp.cfg
%_bindir/osmo-stp
%_unitdir/osmo-stp.service
%_defaultdocdir/%name/
%license COPYING

%changelog
* Fri May 30 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.1
  * asp: Avoid double-free of received msg if conn is teared down
* Thu Feb 13 2025 Jan Engelhardt <jengelh@inai.de>
- Renamed libosmo-sccp to libosmo-sigtran
- Update to release 2.1.0
  * ss7_as: Avoid dispatch event to asp with uninitialized FSM
  * Reject M3UA with "M3UA Network Appearance"
  * SS7: Support secondary point codes
* Sat Oct 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.9.0
  * sccp: Introduce initial support for SCCP LUDT + LUDTS messages
  * asp: Apply SCTP local and peer primary address changes after
    the ASP was started
  * asp: Support removing local & remote addresses
  * Implement M3UA-over-TCP (in addition to SCTP)
* Tue Jun 18 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.2
  * ipa: Use pseudo-random number for SLS in IPA->M3UA direction
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.1
  * SCCP: implement variable limit on Optional Data
    (CR,CC,CREF,RLSD)
  * Allow configuring per-ASP SCTP INIT parameters
* Thu May 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.7.0
  * SIGTRAN: cache Optional Data for SCCP CR/CC/RLSD
* Wed Aug  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * Add ss7 instances to osmo_ss7_instances in creation order
  * M3UA/SUA: Implement handling of SCON (signaling congestion)
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.5.0
  * ipa: Use VTY-configured default network indicator
  * Constrain connection ID allocation to 24 bits
  * m3ua/sua: Add quirk for allowing inbound DAUD from SG in ASP
    role
  * ipa_asp_fsm: Support server starting handshake with ID_GET or
    ID_ACK
  * sccp: Add minimalistic support for XUDT / XUDTS
  * stp: Add basic RX/TX rate counters on AS and ASP level
* Tue Oct  5 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-stp.service.patch
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.0
  * Support setting rt-prio and cpu-affinity mask through VTY
  * Introduce SS7 IPv6 support
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0
  * ss7: Introduce APIs to manage asp_peer hosts
  * sccp: Fix null ptr access on malformed or unsupported msg received
  * sccp: Support receiving messages with no optional params
  * cs7 vty: add 'show cs7 config'
* Sat Aug  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * sccp_internal.h: fix compilation with gcc-10
* Sat Jun  6 2020 Jan Engelhardt <jengelh@inai.de>
- Set CFLAGS+=-fcommon.
* Tue Jan  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update 0001-build-fixes.patch to build sccp_test with SOURCES,
  not LDADD.
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.2.0
  * ASP FSM: Permit DOWN -> DOWN "transition"
  * xua: Implement traffic mode broadcast
  * osmo_ss7: Add osmo_ss7_asp_find()
  * introduce public enum osmo_ss7_asp_role for ASP/SG/IPSP
  * ss7: Implement AS traffic mode loadshare using round robin ASP
    selection
  * ipa: Fix crash when parsing of received IPA SCCP message fails
  * ipa: Don't send non-SCCP data over IPA/SCCPlite
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.0
  * OsmoSTP: enable statsd support
  * osmo-stp: register VTY commands for talloc context introspection
  * osmo-stp: expose root talloc context to the VTY code
* Mon Jan 28 2019 mardnh@gmx.de
- Update to new upstream release 1.0.0
  * Bugfix release only.
    The full changelog is available via
    http://git.osmocom.org/libosmo-sccp/plain/debian/changelog?h=1.0.0
- Update patch:
  * 0001-build-fixes.patch
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.10.0
  * ipa: Patch DPC/OPC information into SCCP Calling/Called Party
    Address
  * ipa: Automatically create / destroy route on IPA
    connect/disconnect
  * ss7: Re-bind xUA server socket after setting new IP
  * osmo_ss7: Register 5000 as default port for IPA/SCCPlite
  * fix infinite recursion with routing by global title
  * fix use after free in osmo_sccp_simple_server_add_clnt()
  * fix memleak in ipa_rx_msg_sccp
  * fix two memleaks in ipa_rx_msg_sccp()
* Sat Mar 17 2018 mardnh@gmx.de
- Derive libversion from version
- Create subpackage for osmo-stp
- Show testsuite.log when tests are failing
- Cosmetic fixes
- Fix url
* Thu Dec 28 2017 jengelh@inai.de
- Update to new upstream release 0.8.1
  * sccp_scrc: fix Network Indicator in SIO composition
  * osmo_sccp_addr_encode(): Fix truncation of point codes
* Thu Oct 26 2017 dimstar@opensuse.org
- Fix names of shared library packages: the version is 0.7.0.284
  and the soname contains the entire version. As this results in
  package rename, we exceptionally obsolete the old/wrong package
  name in order to facilitate error-free upgrades.
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.284
  * vty: add 'asp' / 'local-ip' command
  * osmo_ss7_vty: fix 'as' / 'routing-key' command
  * OsmoSTP: Install our default set of signal handlers
  * Fix SCCP client crash on xUA server (STP) disconnect
  * vty: hide SG commands when running as ASP
  * sccp: fix creating of the default route in simple client
  * sccp: derive local address from given sccp instance
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.208
  * Add new 'osmo_ss7' SS7 core code with M3UA, ASP/AS FSM, ...
  * Add SCCP <-> SUA message transcoding routines
  * Add tests for xUA code + SCCP/SUA transcoding
  * Add new SCCP implementation
  * Add M3UA RKM (routing key management) support, SGW side only
  * SCCP: Add VTY interface for SCCP
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.11
  * Add missing OSMO_SCCP_SSN_RANAP for RANAP SSN
  * Properly define SCCP_SAP_USER without random magic number
  * Import SUA (SCCP User Adaptation) and SCCP User SAP
* Thu Sep 10 2015 jengelh@inai.de
- Update to new upstream release 0.7.0
  * sccp: Allow to specify the context of the incoming message
  * mtp: Correct the pointcode mask
  * mtp: Add implementation from cellmgr
  * m3ua: Add the definition of the protocol data header
  * xua: Generalize the m2ua_msg and call it xua_msg
  * XUA: Move m2ua headers to sigtran, create xua_types.h
  and m3ua_types.h
  * sccp: Create sccp_create_cr and use it in the connection creation
* Mon Jul 21 2014 jengelh@inai.de
- Initial package (version 0.0.6.3) for build.opensuse.org
